@@ -1,5 +1,5 @@
 color.density <- 
-function(x, col.nrm="darkblue", col.gen="blue", col.bg="snow1",  
+function(x, col.nrm="darkblue", col.gen="blue", col.bg="seashell",  
          col.grid="grey90", col.hist="grey86",
          col.fill.nrm=rgb(80,150,200, alpha=70, max=255), 
          col.fill.gen=rgb(250,210,230, alpha=70, max=255),
