@@ -60,7 +60,9 @@ send.to.console(str(mydata, digits.d=15))
 
 cat("\n\n")
 cat(line, "What is next? Try one of the following.", "\n", sep="", line)
-cat("mydata: List all rows (observations) of data.\n")
+cat("mydata: List all rows (observations) of data, or just enter the\n")
+cat("        variable name to see the data just for that variable.\n")
+cat("describe(mydata): A data summary for each variable in the data table.\n")
 cat("help.me(): List of topics for analysis with related R/lessR functions.")
 cat("\n", line, sep="")
 cat("\n")
